@@ -1,5 +1,9 @@
+/* Copyright (C) 2000-2003 Peter Selinger.
+   This file is part of ccrypt. It is free software and it is covered
+   by the GNU general public license. See the file COPYING for details. */
+
 /* readkey.c: read secret key phrase from terminal */
-/* $Id: readkey.c,v 1.1 2001/11/27 10:45:15 selinger Exp $ */
+/* $Id: readkey.c,v 1.4 2003/08/25 18:06:20 selinger Exp $ */
 
 #include <termios.h>
 #include <stdio.h>
@@ -8,7 +12,7 @@
 #include "xalloc.h"
 
 /* read key from /dev/tty */
-char *readkey(char *prompt, char *myname) {
+char *readkey(char *prompt, char *promptcont, char *myname) {
   char *line;
   FILE *fin;
   struct termios tio, saved_tio;
@@ -19,7 +23,7 @@ char *readkey(char *prompt, char *myname) {
     exit(2);
   }
 
-  fprintf(stderr, "%s", prompt);
+  fprintf(stderr, "%s%s", prompt, promptcont);
   fflush(stderr);
 
   /* disable echo */
